@@ -8,7 +8,6 @@ use vars qw($AUTOLOAD);
 use Class::ReturnValue;
 
 
-# {{{ Doc
 
 =head1 NAME
 
@@ -336,13 +335,15 @@ For simple use, thats more or less all there is to it.  In the future, I hope to
 this HowTo to discuss using container classes,  overloading, and what 
 ever else I think of.
 
+=head1 METHOD NAMING
 
+Each method has a lower case alias; '_' is used to separate words.
+For example, the method C<_PrimaryKeys> has the alias C<_primary_keys>.
 
 =head1 METHODS
 
 =cut
 
-# }}}
 
 
 =head2  new 
@@ -352,7 +353,6 @@ Instantiate a new record object.
 =cut
 
 
-
 sub new  {
     my $proto = shift;
    
@@ -364,9 +364,14 @@ sub new  {
     return $self;
   }
 
-# }}}
 
-# {{{ sub Id and id
+# Not yet documented here.  Should almost certainly be overloaded.
+sub _Init {
+    my $self = shift;
+    my $handle = shift;
+    $self->_Handle($handle);
+}
+
 
 =head2 id
 
@@ -375,14 +380,15 @@ Returns this row's primary key.
 =cut
 
 
-*Id = \&id;
 
-sub id  {
+*id = \&Id;
+
+sub Id  {
     my $pkey = $_[0]->_PrimaryKey();
-    $_[0]->{'values'}->{$pkey};
+    my $ret = $_[0]->{'values'}->{$pkey};
+    return $ret;
 }
 
-# }}}
 
 =head2 primary_keys
 
@@ -394,7 +400,7 @@ Return a hash of the values of our primary keys for this function.
 
 
 
-*primary_keys = \&PrimaryKeys;
+
 sub PrimaryKeys { 
     my $self = shift; 
     my %hash = map { $_ => $self->{'values'}->{$_} } @{$self->_PrimaryKeys};
@@ -403,46 +409,51 @@ sub PrimaryKeys {
 
 
 
-# {{{ Routines dealing with getting and setting row data
 
-# {{{ sub DESTROY
 sub DESTROY {
     return 1;
 }
-# }}}
 
-# {{{ sub AUTOLOAD 
 
 sub AUTOLOAD {
-    my $self = shift;
+    my $self = $_[0];
 
     no strict 'refs';
-    my $Attrib;
-    if ( $AUTOLOAD =~ /.*::(\w+)/o ) {
-        $Attrib = $1;
-    } 
-    if ( $Attrib &&  $self->_Accessible( $Attrib, 'read' ) ) {
+    my ($Attrib) = ( $AUTOLOAD =~ /::(\w+)$/o );
+
+    if ( $self->_Accessible( $Attrib, 'read' ) ) {
         *{$AUTOLOAD} = sub { return ( $_[0]->_Value($Attrib) ) };
-        return ( $self->_Value($Attrib) );
+        goto &$AUTOLOAD;
+    }
+    elsif ( $self->_Accessible( $Attrib, 'record-read') ) {
+        *{$AUTOLOAD} = sub { $_[0]->_ToRecord( $Attrib, $_[0]->__Value($Attrib) ) };
+        goto &$AUTOLOAD;        
+    }
+    elsif ( $self->_Accessible( $Attrib, 'foreign-collection') ) {
+        *{$AUTOLOAD} = sub { $_[0]->_CollectionValue( $Attrib ) };
+        goto &$AUTOLOAD;
     }
     elsif ( $AUTOLOAD =~ /.*::[sS]et_?(\w+)/o ) {
-            $Attrib = $1;
+        $Attrib = $1;
 
         if ( $self->_Accessible( $Attrib, 'write' ) ) {
-
             *{$AUTOLOAD} = sub {
                 return ( $_[0]->_Set( Field => $Attrib, Value => $_[1] ) );
             };
-
-            my $Value = shift @_;
-            return ( $self->_Set( Field => $Attrib, Value => $Value ) );
-        }
-
-        elsif ( $self->_Accessible( $Attrib, 'read' ) ) {
+            goto &$AUTOLOAD;
+        } elsif ( $self->_Accessible( $Attrib, 'record-write') ) {
             *{$AUTOLOAD} = sub {
-                return ( 0, 'Immutable field' );
+                my $self = shift;
+                my $val = shift;
+
+                $val = $val->id if UNIVERSAL::isa($val, 'DBIx::SearchBuilder::Record');
+                return ( $self->_Set( Field => $Attrib, Value => $val ) );
             };
-            return ( 0, 'Immutable field' );
+            goto &$AUTOLOAD;            
+        }
+        elsif ( $self->_Accessible( $Attrib, 'read' ) ) {
+            *{$AUTOLOAD} = sub { return ( 0, 'Immutable field' ) };
+            goto &$AUTOLOAD;
         }
         else {
             return ( 0, 'Nonexistant field?' );
@@ -452,13 +463,12 @@ sub AUTOLOAD {
         $Attrib = $1;
         if ( $self->_Accessible( $Attrib, 'object' ) ) {
             *{$AUTOLOAD} = sub {
-                my $s = shift;
-                return $s->_Object(
+                return (shift)->_Object(
                     Field => $Attrib,
                     Args  => [@_],
                 );
             };
-            return $self->_Object( Field => $Attrib, Args => [@_] );
+            goto &$AUTOLOAD;
         }
         else {
             return ( 0, 'No object mapping for field' );
@@ -473,8 +483,7 @@ sub AUTOLOAD {
         $Attrib = $1;
 
         *{$AUTOLOAD} = sub { return ( $_[0]->_Validate( $Attrib, $_[1] ) ) };
-        my $Value = shift @_;
-        return ( $self->_Validate( $Attrib, $Value ) );
+        goto &$AUTOLOAD;
     }
 
     # TODO: if autoload = 0 or 1 _ then a combination of lowercase and _ chars,
@@ -489,9 +498,7 @@ sub AUTOLOAD {
 
 }
 
-# }}}
 
-# {{{ sub _Accessible
 
 =head2 _Accessible KEY MODE
 
@@ -501,7 +508,7 @@ Returns undef unless C<KEY> is accessible in C<MODE> otherwise returns C<MODE> v
 
 =cut
 
-*_accessible = \&_Accessible;
+
 sub _Accessible {
     my $self = shift;
     my $attr = shift;
@@ -512,7 +519,6 @@ sub _Accessible {
     return $attribute->{$mode};
 }
 
-# }}}
 
 
 =head2 _PrimaryKeys
@@ -535,12 +541,13 @@ sub _PrimaryKey {
     return $pkeys->[0];
 }
 
-# {{{ sub _ClassAccessible
 
 =head2 _ClassAccessible 
 
-Preferred and most efficient way to specify fields attributes in a derived
-class. 
+An older way to specify fields attributes in a derived class.
+(The current preferred method is by overriding C<Schema>; if you do
+this and don't override C<_ClassAccessible>, the module will generate
+an appropriate C<_ClassAccessible> based on your C<Schema>.)
 
 Here's an example declaration:
 
@@ -554,11 +561,15 @@ Here's an example declaration:
 
 =cut
 
-# XXX This is stub code to deal with the old way we used to do _Accessible
-# It should never be called by modern code
 
 sub _ClassAccessible {
   my $self = shift;
+  
+  return $self->_ClassAccessibleFromSchema if $self->can('Schema');
+  
+  # XXX This is stub code to deal with the old way we used to do _Accessible
+  # It should never be called by modern code
+  
   my %accessible;
   while ( my $col = shift ) {
     $accessible{$col}->{lc($_)} = 1
@@ -567,7 +578,85 @@ sub _ClassAccessible {
   return(\%accessible);
 }
 
-# }}}
+sub _ClassAccessibleFromSchema {
+  my $self = shift;
+  
+  my $accessible = {};
+  foreach my $key ($self->_PrimaryKeys) {
+   $accessible->{$key} = { 'read' => 1 };
+  };
+  
+  my $schema = $self->Schema;
+  
+  for my $field (keys %$schema) {
+    if ($schema->{$field}{'TYPE'}) {
+        $accessible->{$field} = { 'read' => 1, 'write' => 1 };
+    } elsif (my $refclass = $schema->{$field}{'REFERENCES'}) {
+        if (UNIVERSAL::isa($refclass, 'DBIx::SearchBuilder::Record')) {
+            if ($field =~ /(.*)_id$/) {
+                $accessible->{$field} = { 'read' => 1, 'write' => 1 };
+                $accessible->{$1}     = { 'record-read' => 1, 'column' => $field };
+            } else {
+                $accessible->{$field} = { 'record-read' => 1, 'record-write' => 1 };
+            }
+        } elsif (UNIVERSAL::isa($refclass, 'DBIx::SearchBuilder')) {
+            $accessible->{$field} = { 'foreign-collection' => 1 };
+        } else {
+            warn "Error: $refclass neither Record nor Collection";
+        }
+    }
+  }
+  
+  return $accessible;  
+}
+
+
+sub _ToRecord {
+    my $self = shift;
+    my $field = shift;
+    my $value = shift;
+
+    return unless defined $value;
+    
+    my $schema = $self->Schema;
+    my $description = $schema->{$field} || $schema->{$field . "_id"};
+    
+    die "Can't get schema for $field on $self" unless $description;
+
+    return unless $description;
+    
+    return $value unless $description->{'REFERENCES'};
+    
+    my $classname = $description->{'REFERENCES'};
+
+    return unless UNIVERSAL::isa($classname, 'DBIx::SearchBuilder::Record');
+    
+    # XXX TODO FIXME perhaps this is not what should be passed to new, but it needs it
+    my $object = $classname->new( $self->_Handle );
+    $object->LoadById( $value );
+    return $object;
+}
+
+sub _CollectionValue {
+    my $self = shift;
+    
+    my $method_name =  shift;
+    return unless defined $method_name;
+    
+    my $schema = $self->Schema;
+    my $description = $schema->{$method_name};
+    return unless $description;
+    
+    my $classname = $description->{'REFERENCES'};
+
+    return unless UNIVERSAL::isa($classname, 'DBIx::SearchBuilder');
+    
+    my $coll = $classname->new( Handle => $self->_Handle );
+    
+    $coll->Limit( FIELD => $description->{'KEY'}, VALUE => $self->id);
+    
+    return $coll;
+}
 
 # sub {{{ ReadableAttributes
 
@@ -580,13 +669,11 @@ Returns an array of the attributes of this class defined as "read" => 1 in this
 sub ReadableAttributes {
     my $self = shift;
     my $ca = $self->_ClassAccessible();
-    my @readable = grep { $ca->{$_}->{read}} keys %{$ca};
+    my @readable = grep { $ca->{$_}->{'read'} or $ca->{$_}->{'record-read'} } keys %{$ca};
     return (@readable);
 }
 
-# }}}
 
-# {{{  sub WritableAttributes 
 
 =head2 WritableAttributes
 
@@ -597,15 +684,12 @@ Returns an array of the attributes of this class defined as "write" => 1 in this
 sub WritableAttributes {
     my $self = shift;
     my $ca = $self->_ClassAccessible();
-    my @writable = grep { $ca->{$_}->{write}} keys %{$ca};
-    return (@writable);
-
+    my @writable = grep { $ca->{$_}->{'write'} || $ca->{$_}->{'record-write'} } keys %{$ca};
+    return @writable;
 }
 
-# }}}
 
 
-# {{{ sub __Value {
 
 =head2 __Value
 
@@ -614,10 +698,12 @@ override __Value.
 
 =cut
 
-*__value = \&__Value;
+
 sub __Value {
   my $self = shift;
-  my $field = lc(shift);
+  my $field = lc shift;
+
+  $field = $self->_Accessible($field, "column") if $self->_Accessible($field, "column");
 
   if (!$self->{'fetched'}{$field} and my $id = $self->id() ) {
     my $pkey = $self->_PrimaryKey();
@@ -630,10 +716,10 @@ sub __Value {
     $self->{'fetched'}{$field} = 1;
   }
 
-  return($self->{'values'}{$field});
+  my $value = $self->{'values'}{$field};
+    
+  return $value;
 }
-# }}}
-# {{{ sub _Value 
 
 =head2 _Value
 
@@ -642,15 +728,13 @@ Subclasses can override _Value to insert custom access control.
 
 =cut
 
-*_value = \&_Value;
+
 sub _Value  {
   my $self = shift;
   return ($self->__Value(@_));
 }
 
-# }}}
 
-# {{{ sub _Set 
 
 =head2 _Set
 
@@ -660,7 +744,7 @@ Subclasses can override _Set to insert custom access control.
 
 =cut
 
-*_set = \&_Set;
+
 sub _Set {
     my $self = shift;
     return ($self->__Set(@_));
@@ -668,7 +752,7 @@ sub _Set {
 
 
 
-*__set = \&__Set;
+
 sub __Set {
     my $self = shift;
 
@@ -679,16 +763,12 @@ sub __Set {
         @_
     );
 
-    $args{'Column'}        = $args{'Field'};
-    $args{'IsSQLFunction'} = $args{'IsSQL'};
+    $args{'Column'}        = delete $args{'Field'};
+    $args{'IsSQLFunction'} = delete $args{'IsSQL'};
 
     my $ret = Class::ReturnValue->new();
 
-    ## Cleanup the hash.
-    delete $args{'Field'};
-    delete $args{'IsSQL'};
-
-    unless ( defined( $args{'Column'} ) && $args{'Column'} ) {
+    unless ( $args{'Column'} ) {
         $ret->as_array( 0, 'No column specified' );
         $ret->as_error(
             errno        => 5,
@@ -698,7 +778,16 @@ sub __Set {
         return ( $ret->return_value );
     }
     my $column = lc $args{'Column'};
-    if (    ( defined $self->__Value($column) )
+    if ( !defined( $args{'Value'} ) ) {
+        $ret->as_array( 0, "No value passed to _Set" );
+        $ret->as_error(
+            errno        => 2,
+            do_backtrace => 0,
+            message      => "No value passed to _Set"
+        );
+        return ( $ret->return_value );
+    }
+    elsif (    ( defined $self->__Value($column) )
         and ( $args{'Value'} eq $self->__Value($column) ) )
     {
         $ret->as_array( 0, "That is already the current value" );
@@ -709,15 +798,6 @@ sub __Set {
         );
         return ( $ret->return_value );
     }
-    elsif ( !defined( $args{'Value'} ) ) {
-        $ret->as_array( 0, "No value passed to _Set" );
-        $ret->as_error(
-            errno        => 2,
-            do_backtrace => 0,
-            message      => "No value passed to _Set"
-        );
-        return ( $ret->return_value );
-    }
 
 
 
@@ -783,13 +863,62 @@ sub __Set {
     return ( $ret->return_value );
 }
 
-# }}}
+=head2 _Canonicalize PARAMHASH
+
+This routine massages an input value (VALUE) for FIELD into something that's 
+going to be acceptable.
+
+Takes
+
+=over
+
+=item FIELD
+
+=item VALUE
+
+=item FUNCTION
+
+=back
+
+
+Takes:
+
+=over
+
+=item FIELD
+
+=item VALUE
+
+=item FUNCTION
+
+=back
+
+Returns a replacement VALUE. 
+
+=cut
+
+sub _Canonicalize {
+    my $self = shift;
+    my $field = shift;
+    
+
+
+}
+
+
+=head2 _Validate FIELD VALUE
+
+Validate that VALUE will be an acceptable value for FIELD. 
+
+Currently, this routine does nothing whatsoever. 
+
+If it succeeds (which is always the case right now), returns true. Otherwise returns false.
+
+=cut
+
 
-# {{{ sub _Validate 
 
-#TODO: Implement _Validate.
 
-*_validate = \&_Validate;
 sub _Validate  {
     my $self = shift;
     my $field = shift;
@@ -806,9 +935,7 @@ sub _Validate  {
    return(1); 
   }	
 
-# }}}	
 
-# {{{ sub TruncateValue 
 
 =head2 TruncateValue  KEY VALUE
 
@@ -861,9 +988,7 @@ sub TruncateValue {
     }
 
 }
-# }}}
 
-# {{{ sub _Object 
 
 =head2 _Object
 
@@ -875,6 +1000,10 @@ the object constructor's arguments.
 Subclasses can override _Object to insert custom access control or
 define default contructor arguments.
 
+Note that if you are using a C<Schema> with a C<REFERENCES> field, 
+this is unnecessary: the method to access the column's value will
+automatically turn it into the appropriate object.
+
 =cut
 
 sub _Object {
@@ -897,7 +1026,7 @@ sub __Object {
         eval "require $class";
         die "Couldn't use $class: $@" if ($@);
         unless ( $vglob && *$vglob{'SCALAR'} ) {
-            *{ $class . "::VERSION" } = '-1, By DBIx::SerchBuilder';
+            *{ $class . "::VERSION" } = '-1, By DBIx::SearchBuilder';
         }
     }
 
@@ -906,11 +1035,8 @@ sub __Object {
     return $object;
 }
 
-# }}}
   
-# {{{ routines dealing with loading records
 
-# {{{ sub Load 
 
 # load should do a bit of overloading
 # if we call it with only one argument, we're trying to load by reference.
@@ -926,15 +1052,13 @@ is $id
 =cut
 
 
-*load = \&Load;
+
 sub Load  {
     my $self = shift;
     # my ($package, $filename, $line) = caller;
     return $self->LoadById(@_);
 }
 
-# }}}
-# {{{ sub LoadByCol 
 
 =head2 LoadByCol
 
@@ -944,7 +1068,7 @@ undefined
 
 =cut
 
-*load_by_col = \&LoadByCol;
+
 
 sub LoadByCol  {
     my $self = shift;
@@ -954,9 +1078,7 @@ sub LoadByCol  {
     return($self->LoadByCols($col => $val));
 }
 
-# }}}
 
-# {{{ sub LoadByCols
 
 =head2 LoadByCols
 
@@ -970,7 +1092,7 @@ OR has references which contain 'operator' and 'value'
 
 =cut
 
-*load_by_cols = \&LoadByCols;
+
 sub LoadByCols  {
     my $self = shift;
     my %hash  = (@_);
@@ -993,7 +1115,16 @@ sub LoadByCols  {
 		push @bind, $value;
 	}
 	else {
-		push @phrases, "($key IS NULL OR $key = '')";
+       push @phrases, "($key IS NULL OR $key = ?)";
+       my $meta = $self->_ClassAccessible->{$key};
+       $meta->{'type'} ||= '';
+       # TODO: type checking should be done in generic way
+       if ( $meta->{'is_numeric'} || $meta->{'type'} =~ /INT|NUMERIC|DECIMAL|REAL|DOUBLE|FLOAT/i  ) {
+            push @bind, 0;
+       } else {
+            push @bind, '';
+       }
+
 	}
     }
     
@@ -1003,9 +1134,7 @@ sub LoadByCols  {
 }
 
 
-# }}}
 
-# {{{ sub LoadById 
 
 =head2 LoadById
 
@@ -1013,7 +1142,7 @@ Loads a record by its primary key. Your record class must define a single primar
 
 =cut
 
-*load_by_id = \&LoadById;
+
 sub LoadById  {
     my $self = shift;
     my $id = shift;
@@ -1023,10 +1152,8 @@ sub LoadById  {
     return ($self->LoadByCols($pkey => $id));
 }
 
-# }}}  
 
 
-# {{{ LoadByPrimaryKeys 
 
 =head2 LoadByPrimaryKeys 
 
@@ -1034,27 +1161,22 @@ Like LoadById with basic support for compound primary keys.
 
 =cut
 
-*load_by_primary_keys = \&LoadByPrimaryKeys;
+
 
 sub LoadByPrimaryKeys {
-    my ($self, $data) = @_;
+    my $self = shift;
+    my $data = (ref $_[0] eq 'HASH')? $_[0]: {@_};
 
-    if (ref($data) eq 'HASH') {
-       my %cols=();
-       foreach (@{$self->_PrimaryKeys}) {
-         $cols{$_}=$data->{$_} if (exists($data->{$_}));
-       }
-       return ($self->LoadByCols(%cols));
-    } 
-    else { 
-      return (0, "Invalid data");
+    my %cols=();
+    foreach (@{$self->_PrimaryKeys}) {
+	return (0, "Missing PK field: '$_'") unless defined $data->{$_};
+	$cols{$_}=$data->{$_};
     }
+    return ($self->LoadByCols(%cols));
 }
 
-# }}}
 
 
-# {{{ sub LoadFromHash
 
 =head2 LoadFromHash
 
@@ -1063,7 +1185,7 @@ loaded values hash.
 
 =cut
 
-*load_from_hash = \&LoadFromHash;
+
 
 sub LoadFromHash {
   my $self = shift;
@@ -1077,9 +1199,7 @@ sub LoadFromHash {
   return $self->id();
 }
 
-# }}}
 
-# {{{ sub _LoadFromSQL 
 
 =head2 _LoadFromSQL QUERYSTRING @BIND_VALUES
 
@@ -1087,7 +1207,7 @@ Load a record as the result of an SQL statement
 
 =cut
 
-*load_from_sql = \&LoadFromSQL;
+
 
 
 sub _LoadFromSQL {
@@ -1099,42 +1219,35 @@ sub _LoadFromSQL {
 
     #TODO this only gets the first row. we should check if there are more.
 
-    unless ($sth) {
-        return($sth);
-    }
+    return ( 0, "Couldn't execute query" ) unless $sth;
 
-    eval { $self->{'values'} = $sth->fetchrow_hashref; };
-    if ($@) {
-        warn $@;
+    $self->{'values'} = $sth->fetchrow_hashref;
+    $self->{'fetched'} = {};
+    if ( !$self->{'values'} && $sth->err ) {
+        return ( 0, "Couldn't fetch row: ". $sth->err );
     }
 
     unless ( $self->{'values'} ) {
         return ( 0, "Couldn't find row" );
     }
 
-    
-    foreach my $f ( keys %{$self->{'values'}||{}} ) {
-        $self->{'fetched'}{lc $f} = 1;
-    }
-
     ## I guess to be consistant with the old code, make sure the primary  
     ## keys exist.
 
-    eval { $self->PrimaryKeys(); };
-    if ($@) {
-        return ( 0, "Missing a primary key?: $@" );
+    if( grep { not defined } $self->PrimaryKeys ) {
+        return ( 0, "Missing a primary key?" );
+    }
+    
+    foreach my $f ( keys %{$self->{'values'}} ) {
+        $self->{'fetched'}{lc $f} = 1;
     }
     return ( 1, "Found Object" );
 
 }
 
-# }}}
 
-# }}}
 
-# {{{ Routines dealing with creating or deleting rows in the DB
 
-# {{{ sub Create 
 
 =head2 Create
 
@@ -1143,7 +1256,7 @@ as columns for this recordtype
 
 =cut 
 
-*create = \&Create;
+
 
 sub Create {
     my $self    = shift;
@@ -1151,21 +1264,25 @@ sub Create {
 
     my ($key);
     foreach $key ( keys %attribs ) {
-        my $method = "Validate$key";
 
-            #Truncate things that are too long for their datatypes
-        $attribs{$key} = $self->TruncateValue ($key => $attribs{$key});
-
-        unless ( $self->$method( $attribs{$key} ) ) {
-            delete $attribs{$key};
+        if ( $self->_Accessible( $key, 'record-write' ) ) {
+            $attribs{$key} = $attribs{$key}->id
+              if UNIVERSAL::isa( $attribs{$key},
+                'DBIx::SearchBuilder::Record' );
         }
+
+        #Truncate things that are too long for their datatypes
+        $attribs{$key} = $self->TruncateValue( $key => $attribs{$key} );
+
     }
     unless ( $self->_Handle->KnowsBLOBs ) {
+
         # Support for databases which don't deal with LOBs automatically
         my $ca = $self->_ClassAccessible();
         foreach $key ( keys %attribs ) {
             if ( $ca->{$key}->{'type'} =~ /^(text|longtext|clob|blob|lob)$/i ) {
-                my $bhash = $self->_Handle->BLOBParams( $key, $ca->{$key}->{'type'} );
+                my $bhash =
+                  $self->_Handle->BLOBParams( $key, $ca->{$key}->{'type'} );
                 $bhash->{'value'} = $attribs{$key};
                 $attribs{$key} = $bhash;
             }
@@ -1174,9 +1291,6 @@ sub Create {
     return ( $self->_Handle->Insert( $self->Table, %attribs ) );
 }
 
-# }}}
-
-# {{{ sub Delete 
 
 =head2 Delete
 
@@ -1216,12 +1330,9 @@ sub __Delete {
     } 
 }
 
-# }}}
-
-# }}}
 
 
-# {{{ sub Table
+
 
 =head2 Table
 
@@ -1229,7 +1340,7 @@ Returns or sets the name of the current Table
 
 =cut
 
-*table = \&Table;
+
 
 sub Table {
     my $self = shift;
@@ -1239,9 +1350,7 @@ sub Table {
     return ($self->{'table'});
 }
 
-# }}}
 
-# {{{ sub _Handle 
 
 =head2 _Handle
 
@@ -1249,7 +1358,7 @@ Returns or sets the current DBIx::SearchBuilder::Handle object
 
 =cut
 
-*_handle = \&_Handle;
+
 sub _Handle  {
     my $self = shift;
     if (@_) {
@@ -1258,14 +1367,15 @@ sub _Handle  {
     return ($self->{'DBIxHandle'});
   }
 
-# }}}
 
+if( eval { require capitalization } ) {
+	capitalization->unimport( __PACKAGE__ );
+}
 
 1;
 
 __END__
 
-# {{{ POD
 
 
 =head1 AUTHOR
@@ -1282,5 +1392,4 @@ L<DBIx::SearchBuilder>
 
 =cut
 
-# }}}
 
